@@ -4,16 +4,16 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.3'; # VERSION
+our $VERSION = 'v0.2.4'; # VERSION
 
 use Moose::Role;
 with qw(
 	Business::CyberSource::Role::Currency
 );
 
-use MooseX::Types::Moose         qw( Num Str     );
+use MooseX::Types::Moose         qw( Num );
+use MooseX::Types::Varchar       qw( Varchar );
 use MooseX::Types::DateTime::W3C qw( DateTimeW3C );
-use MooseX::Types::Varchar       qw( Varchar     );
 
 
 has amount => (
@@ -38,6 +38,7 @@ has reference_code => (
 
 # ABSTRACT: role for handling accepted transactions
 
+
 __END__
 =pod
 
@@ -47,7 +48,37 @@ Business::CyberSource::Response::Role::Accept - role for handling accepted trans
 
 =head1 VERSION
 
-version v0.2.3
+version v0.2.4
+
+=head1 DESCRIPTION
+
+If the transaction has a C<decision> of approved then this Role is applied.
+
+=head1 ATTRIBUTES
+
+=head2 amount
+
+Type: Num
+
+Amount that was approved.
+
+=head2 currency
+
+Type: MooseX::Types::Locale::Currency
+
+Currency code which was used to make the request
+
+=head2 datetime
+
+Type: MooseX::Types::DateTime::W3C::DateTimeW3C
+
+Request timestamp (will probably become a DateTime object at some point)
+
+=head2 reference_code
+
+Type: MooseX::Types::Varchar::Varchar[50]
+
+The merchant reference code originally sent
 
 =head1 BUGS
 
