@@ -2,21 +2,24 @@ package Business::CyberSource::Response::Role::AuthReversal;
 use 5.008;
 use strict;
 use warnings;
-BEGIN {
-	our $VERSION = 'v0.2.3'; # VERSION
-}
+use namespace::autoclean;
+
+our $VERSION = 'v0.2.4'; # VERSION
+
 use Moose::Role;
+use MooseX::Types::Varchar qw( Varchar );
+use MooseX::Types::Moose   qw( Int     );
 
 has processor_response => (
 	required => 1,
 	is       => 'ro',
-	isa      => 'Str',
+	isa      => Varchar[10]
 );
 
 has reversal_reason_code => (
 	required => 1,
 	is       => 'ro',
-	isa      => 'Num',
+	isa      => Int, # 5
 );
 
 1;
@@ -32,7 +35,7 @@ Business::CyberSource::Response::Role::AuthReversal - Role for Authorization Rev
 
 =head1 VERSION
 
-version v0.2.3
+version v0.2.4
 
 =head1 BUGS
 
