@@ -2,21 +2,16 @@ package Business::CyberSource::Response::Role::Authorization;
 use 5.008;
 use strict;
 use warnings;
-BEGIN {
-	our $VERSION = 'v0.2.3'; # VERSION
-}
-use Moose::Role;
 
-has request_token => (
-	required => 1,
-	is       => 'ro',
-	isa      => 'Str',
-);
+our $VERSION = 'v0.2.4'; # VERSION
+
+use Moose::Role;
+use MooseX::Types::Varchar qw( Varchar );
 
 has auth_code => (
 	required => 1,
 	is       => 'ro',
-	isa      => 'Num',
+	isa      => Varchar[7],
 );
 
 has auth_record => (
@@ -28,35 +23,38 @@ has auth_record => (
 has avs_code => (
 	required => 1,
 	is       => 'ro',
-	isa      => 'Str',
+	isa      => Varchar[1],
+	documentation => 'AVS results.',
 );
 
 has avs_code_raw => (
-	required => 1,
+	required => 0,
 	is       => 'ro',
-	isa      => 'Str',
+	isa      => Varchar[10],
+	documentation => 'AVS result code sent directly from the processor. '
+		. 'Returned only if a value is returned by the processor.',
 );
 
 has processor_response => (
 	required => 1,
 	is       => 'ro',
-	isa      => 'Str',
+	isa      => Varchar[10],
 );
 
 1;
 
-# ABSTRACT: CyberSource Authorization Response object
+# ABSTRACT: CyberSource Authorization Response only attributes
 
 __END__
 =pod
 
 =head1 NAME
 
-Business::CyberSource::Response::Role::Authorization - CyberSource Authorization Response object
+Business::CyberSource::Response::Role::Authorization - CyberSource Authorization Response only attributes
 
 =head1 VERSION
 
-version v0.2.3
+version v0.2.4
 
 =head1 BUGS
 
